/**
 *****************************************************************************
   @example  Blinky.c
   @brief    RTX example program
             
   @version  V0.1
   @author   ADI
   @date     June 2014 

              
All files for ADuCM320 provided by ADI, including this file, are
provided  as is without warranty of any kind, either expressed or implied.
The user assumes any and all risk from the use of this code.
It is the responsibility of the person integrating this code into an application
to ensure that the resulting application performs as required and is safe.

**/

#include <stdio.h>
#include <cmsis_os.h>
#include <aducm320.h>
#include "serial.h"

osThreadId t_ledOn;                         /* assigned task id of task: ledOn   */
osThreadId t_ledOff;                        /* assigned task id of task: ledOff  */

int once = 1;
/*----------------------------------------------------------------------------
  Task 1 'ledOn': switches the LED on
 *---------------------------------------------------------------------------*/
void ledOn (void const *argument) {
   for (;;) {
      pADI_GP2->GPCLR |= 0x10;               /* clear P2.4 - turn LED on */
      osSignalSet (t_ledOff, 0x0001);        /* send event to task 'ledoff'       */
      osDelay (1000);                        /* delay 1000 ms                      */
   }
}

/*----------------------------------------------------------------------------
  Task 2 'ledOff': switches the LED off
 *---------------------------------------------------------------------------*/
void ledOff (void const *argument) {
   for (;;) {
      osSignalWait (0x0001, osWaitForever);   /* wait for an event flag 0x0001     */
      osDelay (800);                          /* delay 800 ms                      */
      pADI_GP2->GPSET |= 0x10;                /* set P2.4 - turn LED off */  
   }
}

osThreadDef(ledOn,  osPriorityNormal, 1, 0);
osThreadDef(ledOff, osPriorityNormal, 1, 0);

/*----------------------------------------------------------------------------
  Main: Initialize and start RTX Kernel
 *---------------------------------------------------------------------------*/
int main (void) {

   SystemCoreClockUpdate();
   pADI_WDT ->T3CON = 0;  //Disable watchdog
   pADI_RESET->RSTKEY =  0x2009;                   //By Default Software and Watchdog resets don't reset the LV die and GPIOs
   pADI_RESET->RSTKEY =  0x0426;                   //During debug it's useful that Software tools have the ability to reset them
   pADI_RESET->RSTCFG = RSTCFG_GPIO_PLA_RETAIN_DIS;//So disable retain function during debug.

   pADI_GP2->GPOE |= 0x10;  //enable P2.4 output pin connected to LED
   SER_Init (); 
   printf ("Hello World\n\r");


   t_ledOn  = osThreadCreate(osThread(ledOn),  NULL);
   t_ledOff = osThreadCreate(osThread(ledOff), NULL);
   osDelay(osWaitForever);
   while(1);

}

