/*-----------------------------------------------------------------------------
 * Name:    Serial.c
 * Purpose: Serial Input Output for ADuCM320
 * Note(s): Possible defines to select the used communication interface:
 *            __DBG_ITM   - ITM SWO interface
 *                        - UART is used by default
 *-----------------------------------------------------------------------------
 * All files for ADuCM320 provided by ADI, including this file, are
 * provided  as is without warranty of any kind, either expressed or implied.
 * The user assumes any and all risk from the use of this code.
 * It is the responsibility of the person integrating this code into an application
 * to ensure that the resulting application performs as required and is safe.
 *----------------------------------------------------------------------------*/

#include <ADuCM320.H>
#include "Serial.h"

#ifdef __DBG_ITM
volatile int ITM_RxBuffer = ITM_RXBUFFER_EMPTY;  /*  CMSIS Debug Input        */
#endif


/*-----------------------------------------------------------------------------
 *       SER_Init:  Initialize Serial Interface
 *----------------------------------------------------------------------------*/
void SER_Init (void) {
#ifndef __DBG_ITM

  pADI_GP1->GPCON = ((1UL << (0*2)) |                   /* P1.0 = UART RX     */
                     (1UL << (1*2))  );                 /* P1.1 = UART TX     */

  pADI_UART->COMLCR = ((0UL << 3) |                     /* no Parity          */
                       (0UL << 2) |                     /* 1 Stop bit         */
                       (3UL << 0)  );                   /* 8 Data bits        */
                                                        /* 115200Baud @ 80MHz */
  pADI_UART->COMDIV =  (5UL << 0);                      /* COMDIV = 5         */
  pADI_UART->COMFBR = ((  1UL << 15) |                  /* enable FBRG        */
                       (  1UL << 11) |                  /* DIVM = 1           */
                       (174UL <<  0)  );                /* DIVN = 174         */
#endif
}


/*-----------------------------------------------------------------------------
 *       SER_PutChar:  Write a character to the Serial Port
 *----------------------------------------------------------------------------*/
int32_t SER_PutChar (int32_t ch) {

#ifdef __DBG_ITM
  ITM_SendChar (ch & 0xFF);
#else
  while (!(pADI_UART->COMLSR & 0x20));
  pADI_UART->COMTX = ch;
#endif  

  return (ch);
}


/*-----------------------------------------------------------------------------
 *       SER_GetChar:  Read a character from the Serial Port (non-blocking)
 *----------------------------------------------------------------------------*/
int32_t SER_GetChar (void) {

#ifdef __DBG_ITM
  if (ITM_CheckChar())
    return ITM_ReceiveChar();
#else
  if (pADI_UART->COMLSR & 0x01) {
    return (pADI_UART->COMRX);
  }
#endif
  return (-1);
}
